==> qg_toolkit-1.0.41-py3-none-any.whl: qg_toolkit/tools/rpc.py <==
endpoints = {
    "mainnet": "https://mainnet.infura.io/v3/257c5f3bdfed414b88a4908b0f999377",
    # "bsc": "https://data-seed-prebsc-1-s1.binance.org:8545",
    # "bsc": 'https://1gwei.48.club',
    "bsc": "https://rpc.ankr.com/bsc",
    # "bsc": "https://bsc.blockpi.network/v1/rpc/eee28a206a110cf0d0b58371cfbfae4ee5864bfb",
    # "bsc": "https://go.getblock.io/4f453487a0f4424f82b7bb2e0026e8d4",
    # "bsc": "https://bsc.blockpi.network/v1/rpc/public",
    # "bsc": "https://bsc-dataseed2.defibit.io",
    "goerli": "https://eth-goerli.g.alchemy.com/v2/hLTAisSN98aFruQM7qYQC8EBP4tjfymv",
    # "goerli": "https://goerli.blockpi.network/v1/rpc/public",
    # "goerli": "https://ethereum-goerli.publicnode.com",
    # "goerli": "https://goerli.gateway.tenderly.co",
    # "goerli": "https://eth-goerli.public.blastapi.io",
    # "goerli": "https://eth-goerli.api.onfinality.io/public",
    "sepolia": "https://rpc.sepolia.org",
    "linea": "https://linea.blockpi.network/v1/rpc/public",
    "linea_test": "https://rpc.goerli.linea.build",
    "scroll_test": "https://alpha-rpc.scroll.io/l2",
    # "scroll": "https://rpc.ankr.com/scroll",
    "scroll": "https://1rpc.io/scroll",
    # "scroll": "https://rpc-scroll.icecreamswap.com",
    "shib": "https://www.shibrpc.com",
    "taiko": "https://rpc.mainnet.taiko.xyz/",
    "taikol3": "https://rpc.l3test.taiko.xyz",
    "taiko_jolnir": "https://taiko-jolnir.blockpi.network/v1/rpc/public",
    "mantle": "https://rpc.mantle.xyz",
    "mantle_test": "https://rpc.ankr.com/mantle_testnet",
    # "base_goerli": "https://chain-proxy.wallet.coinbase.com?targetName=base-goerli"
    "base_goerli": "https://goerli.base.org",
    "zora": "https://testnet.rpc.zora.co",
    "omni": "https://testnet-1.omni.network",
    "base": "https://developer-access-mainnet.base.org",
    "combo": "https://test-rpc.combonetwork.io",
    # "zeta": "https://zetachain-evm.blockpi.network/v1/rpc/public",
    "zeta": "https://zetachain-mainnet-archive.allthatnode.com:8545",
    "zeta2": "https://api.athens2.zetachain.com/evm",
    "zeta3": "https://rpc.ankr.com/zetachain_evm_athens_testnet",
    "bsc_test": "https://data-seed-prebsc-1-s1.binance.org:8545/",
    "opbnb": "https://opbnb-mainnet-rpc.bnbchain.org",
    # "polygon": "https://rpc.ankr.com/polygon",
    "polygon": "https://polygon-bor.publicnode.com",
    # "polygon": "https://polygon-rpc.com",
    # "polygon": "https://polygon-mainnet.infura.io/v3/e033cdd0b4464967924989bbdcf18e12",
    "heco": "https://http-mainnet-node.huobichain.com",
    "ftm": "https://rpc3.fantom.network",
    "etc": "https://etc.rivet.link",
    # "etc": "https://etc.mytokenpocket.vip",
    # "etc": "https://etc.etcdesktop.com",
    # "etc": "https://besu-at.etc-network.info",
    "manta": "https://1rpc.io/manta",
    "arb": "https://arb1.arbitrum.io/rpc",
    "xter": "https://xterio.alt.technology/",
    # "arb": "https://arbitrum.blockpi.network/v1/rpc/public",
    # "arb": "https://arb-pokt.nodies.app",
    # "fil": "https://filecoin.chainup.net/rpc/v1",
    # "fil": 'https://filfox.info/rpc/v1',
    # "fil": "https://rpc.ankr.com/filecoin",
    # "fil": "https://node.filutils.com/rpc/v1",
    # "fil": "https://rpc.ankr.com/filecoin/3cdc25144192cd85f8d3cbfec024a46ec7442019996b70f7cfa368632f952641",
    "eos": "https://api.evm.eosnetwork.com",
    # "kcs": "https://kcc-rpc.com",
    # "kcs": "https://rpc-mainnet.kcc.network",
    # "kcs": "https://kcc-rpc.com",
    "kcs": "https://rpc-mainnet.kcc.network",
    # "kcs": "https://wallet.okex.org/priapi/v1/wallet/rpc/send?chainId=321"
    # "cfx": "https://evm.confluxrpc.com",
    # "cfx": "https://conflux-espace-public.unifra.io",
    "cfx": "https://cfx-espace.unifra.io/v1/271d5d84bd4b4344a56589e2db07f4f6",
    # "avav": "https://avalanche.blockpi.network/v1/rpc/public",
    # "avav": "https://rpc.ankr.com/avalanche",
    "avav": "https://avalanche.drpc.org",
    # "avav": "https://avax-pokt.nodies.app/ext/bc/C/rpc",
    "berachain": "https://artio.rpc.berachain.com",
    "kly": "https://public-en-cypress.klaytn.net",
    "blast": "https://sepolia.blast.io",
    "holesky": "https://ethereum-holesky.publicnode.com",
    "katla": "https://rpc.katla.taiko.xyz",
    "hekla": "https://rpc.hekla.taiko.xyz",
    "plume_test": "https://testnet-rpc.plumenetwork.xyz/http"
}
# api接口
bases = {
    "goerli": "https://api-goerli.etherscan.io/api",
    # "goerli": "https://eth-goerli.blockscout.com/api",
    "sepolia": "https://api-sepolia.etherscan.io/api",
    # "linea": "https://explorer.goerli.linea.build/api",
    "linea": "https://api-testnet.lineascan.build/api",
    "mantle": "https://explorer.mantle.xyz/api",
    "mantle_test": "https://explorer.testnet.mantle.xyz/api",
    "zora": "https://testnet.explorer.zora.energy/api",
    "omni": "https://testnet-1.explorer.omni.network/api",
    "bsc": "https://api.bscscan.com/api",
    "taiko": "https://explorer.test.taiko.xyz/api",
    "taikol3": "https://blockscoutapi.l3test.taiko.xyz/api",
    "combo": "https://api-combotrace-testnet.nodereal.io/api",
    "zeta": "https://zetachain.blockpi.network:443/rpc/v1/public/api",
    "zeta2": "https://rpc.ankr.com/http/zetachain_tendermint_athens_testnet/api",
    "zeta3": "https://zetachain-athens-evm.blockpi.network/v1/rpc/public/api",
    # "zeta3": "https://rpc.ankr.com/zetachain_evm_athens_testnet/995de8736b54e4c2b5ec62771fe384c27c9715835a9ccf0d0fd11c8eaf985095/api",
    "bsc_test": "https://api-testnet.bscscan.com/api",
    "opbnb": "https://opbnb-mainnet.nodereal.io/v1/b4876385e7ec46cd9da933f2a83d969c",
    "polygon": "https://api.polygonscan.com/api",
    "berachain": "https://api.routescan.io/v2/network/testnet/evm/80085/etherscan/api",
    "blast": "https://api.routescan.io/v2/network/testnet/evm/168587773/etherscan/api",
    "holesky": "https://ethereum-holesky-beacon-api.publicnode.com",
    "xter": "https://xterscan.io/api"
}

apis = {
    "get_account_tx_list": "?module=account&action=txlist&address={}",
    "get_tx_info": "?module=transaction&action=gettxinfo&txhash={}"
}

==> qg_toolkit-1.1.4-py3-none-any.whl: qg_toolkit/tools/rpc.py <==
endpoints = {
    "mainnet": "https://mainnet.infura.io/v3/257c5f3bdfed414b88a4908b0f999377",
    # "bsc": "https://data-seed-prebsc-1-s1.binance.org:8545",
    # "bsc": 'https://1gwei.48.club',
    "bsc": "https://rpc.ankr.com/bsc",
    # "bsc": "https://bsc.blockpi.network/v1/rpc/eee28a206a110cf0d0b58371cfbfae4ee5864bfb",
    # "bsc": "https://go.getblock.io/4f453487a0f4424f82b7bb2e0026e8d4",
    # "bsc": "https://bsc.blockpi.network/v1/rpc/public",
    # "bsc": "https://bsc-dataseed2.defibit.io",
    "goerli": "https://eth-goerli.g.alchemy.com/v2/hLTAisSN98aFruQM7qYQC8EBP4tjfymv",
    # "goerli": "https://goerli.blockpi.network/v1/rpc/public",
    # "goerli": "https://ethereum-goerli.publicnode.com",
    # "goerli": "https://goerli.gateway.tenderly.co",
    # "goerli": "https://eth-goerli.public.blastapi.io",
    # "goerli": "https://eth-goerli.api.onfinality.io/public",
    "sepolia": "https://rpc.sepolia.org",
    "linea": "https://linea.blockpi.network/v1/rpc/public",
    "linea_test": "https://rpc.goerli.linea.build",
    "scroll_test": "https://alpha-rpc.scroll.io/l2",
    # "scroll": "https://rpc.ankr.com/scroll",
    "scroll": "https://1rpc.io/scroll",
    # "scroll": "https://rpc-scroll.icecreamswap.com",
    "shib": "https://www.shibrpc.com",
    "taiko": "https://rpc.mainnet.taiko.xyz/",
    "taikol3": "https://rpc.l3test.taiko.xyz",
    "taiko_jolnir": "https://taiko-jolnir.blockpi.network/v1/rpc/public",
    "mantle": "https://rpc.mantle.xyz",
    "mantle_test": "https://rpc.ankr.com/mantle_testnet",
    # "base_goerli": "https://chain-proxy.wallet.coinbase.com?targetName=base-goerli"
    "base_goerli": "https://goerli.base.org",
    "zora": "https://testnet.rpc.zora.co",
    "omni": "https://testnet-1.omni.network",
    "base": "https://developer-access-mainnet.base.org",
    "combo": "https://test-rpc.combonetwork.io",
    # "zeta": "https://zetachain-evm.blockpi.network/v1/rpc/public",
    "zeta": "https://zetachain-mainnet-archive.allthatnode.com:8545",
    "zeta2": "https://api.athens2.zetachain.com/evm",
    "zeta3": "https://rpc.ankr.com/zetachain_evm_athens_testnet",
    "bsc_test": "https://data-seed-prebsc-1-s1.binance.org:8545/",
    "opbnb": "https://opbnb-mainnet-rpc.bnbchain.org",
    # "polygon": "https://rpc.ankr.com/polygon",
    "polygon": "https://polygon-bor.publicnode.com",
    # "polygon": "https://polygon-rpc.com",
    # "polygon": "https://polygon-mainnet.infura.io/v3/e033cdd0b4464967924989bbdcf18e12",
    "heco": "https://http-mainnet-node.huobichain.com",
    "ftm": "https://rpc3.fantom.network",
    "etc": "https://etc.rivet.link",
    # "etc": "https://etc.mytokenpocket.vip",
    # "etc": "https://etc.etcdesktop.com",
    # "etc": "https://besu-at.etc-network.info",
    "manta": "https://1rpc.io/manta",
    "arb": "https://arb1.arbitrum.io/rpc",
    "xter": "https://xterio.alt.technology/",
    # "arb": "https://arbitrum.blockpi.network/v1/rpc/public",
    # "arb": "https://arb-pokt.nodies.app",
    # "fil": "https://filecoin.chainup.net/rpc/v1",
    # "fil": 'https://filfox.info/rpc/v1',
    # "fil": "https://rpc.ankr.com/filecoin",
    # "fil": "https://node.filutils.com/rpc/v1",
    # "fil": "https://rpc.ankr.com/filecoin/3cdc25144192cd85f8d3cbfec024a46ec7442019996b70f7cfa368632f952641",
    "eos": "https://api.evm.eosnetwork.com",
    # "kcs": "https://kcc-rpc.com",
    # "kcs": "https://rpc-mainnet.kcc.network",
    # "kcs": "https://kcc-rpc.com",
    "kcs": "https://rpc-mainnet.kcc.network",
    # "kcs": "https://wallet.okex.org/priapi/v1/wallet/rpc/send?chainId=321"
    # "cfx": "https://evm.confluxrpc.com",
    # "cfx": "https://conflux-espace-public.unifra.io",
    "cfx": "https://cfx-espace.unifra.io/v1/271d5d84bd4b4344a56589e2db07f4f6",
    # "avav": "https://avalanche.blockpi.network/v1/rpc/public",
    # "avav": "https://rpc.ankr.com/avalanche",
    "avav": "https://avalanche.drpc.org",
    # "avav": "https://avax-pokt.nodies.app/ext/bc/C/rpc",
    "berachain": "https://artio.rpc.berachain.com",
    "berachain2": "https://bartio.rpc.berachain.com",
    "kly": "https://public-en-cypress.klaytn.net",
    "blast": "https://sepolia.blast.io",
    "holesky": "https://ethereum-holesky.publicnode.com",
    "katla": "https://rpc.katla.taiko.xyz",
    "hekla": "https://rpc.hekla.taiko.xyz",
    "plume_test": "https://161221135.rpc.thirdweb.com/c1bf53e42f440a3597b0fc49b8cc5b4b",
    "chainbase": "https://testnet.s.chainbase.com",
    "story": "https://odyssey.storyrpc.io"
}
# api接口
bases = {
    "goerli": "https://api-goerli.etherscan.io/api",
    # "goerli": "https://eth-goerli.blockscout.com/api",
    "sepolia": "https://api-sepolia.etherscan.io/api",
    # "linea": "https://explorer.goerli.linea.build/api",
    "linea": "https://api-testnet.lineascan.build/api",
    "mantle": "https://explorer.mantle.xyz/api",
    "mantle_test": "https://explorer.testnet.mantle.xyz/api",
    "zora": "https://testnet.explorer.zora.energy/api",
    "omni": "https://testnet-1.explorer.omni.network/api",
    "bsc": "https://api.bscscan.com/api",
    "taiko": "https://explorer.test.taiko.xyz/api",
    "taikol3": "https://blockscoutapi.l3test.taiko.xyz/api",
    "combo": "https://api-combotrace-testnet.nodereal.io/api",
    "zeta": "https://zetachain.blockpi.network:443/rpc/v1/public/api",
    "zeta2": "https://rpc.ankr.com/http/zetachain_tendermint_athens_testnet/api",
    "zeta3": "https://zetachain-athens-evm.blockpi.network/v1/rpc/public/api",
    # "zeta3": "https://rpc.ankr.com/zetachain_evm_athens_testnet/995de8736b54e4c2b5ec62771fe384c27c9715835a9ccf0d0fd11c8eaf985095/api",
    "bsc_test": "https://api-testnet.bscscan.com/api",
    "opbnb": "https://opbnb-mainnet.nodereal.io/v1/b4876385e7ec46cd9da933f2a83d969c",
    "polygon": "https://api.polygonscan.com/api",
    "berachain": "https://api.routescan.io/v2/network/testnet/evm/80085/etherscan/api",
    "berachain2": "https://api.routescan.io/v2/network/testnet/evm/80084/etherscan/api",
    "blast": "https://api.routescan.io/v2/network/testnet/evm/168587773/etherscan/api",
    "holesky": "https://ethereum-holesky-beacon-api.publicnode.com",
    "xter": "https://xterscan.io/api"
}

apis = {
    "get_account_tx_list": "?module=account&action=txlist&address={}",
    "get_tx_info": "?module=transaction&action=gettxinfo&txhash={}"
}
